==> eam-wshub-proxyclient-11.4-5-sources.jar: net/datastream/schemas/mp_entities/substitutepart_001/SubstitutePart.java <==

package net.datastream.schemas.mp_entities.substitutepart_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.SUBSTITUTEPART_Type;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SUBSTITUTEPARTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FULLYCOMPATIBLE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTCONDITIONTEMPLATECONDITIONCODE" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "substitutepartid",
    "fullycompatible",
    "partconditiontemplateconditioncode"
})
@XmlRootElement(name = "SubstitutePart")
public class SubstitutePart {

    @XmlElement(name = "SUBSTITUTEPARTID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected SUBSTITUTEPART_Type substitutepartid;
    @XmlElement(name = "FULLYCOMPATIBLE", namespace = "http://schemas.datastream.net/MP_fields", required = true, defaultValue = "false")
    protected String fullycompatible;
    @XmlElement(name = "PARTCONDITIONTEMPLATECONDITIONCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String partconditiontemplateconditioncode;
    @XmlAttribute(name = "recordid")
    protected Long recordid;

    /**
     * Obtient la valeur de la propriété substitutepartid.
     * 
     * @return
     *     possible object is
     *     {@link SUBSTITUTEPART_Type }
     *     
     */
    public SUBSTITUTEPART_Type getSUBSTITUTEPARTID() {
        return substitutepartid;
    }

    /**
     * Définit la valeur de la propriété substitutepartid.
     * 
     * @param value
     *     allowed object is
     *     {@link SUBSTITUTEPART_Type }
     *     
     */
    public void setSUBSTITUTEPARTID(SUBSTITUTEPART_Type value) {
        this.substitutepartid = value;
    }

    /**
     * Obtient la valeur de la propriété fullycompatible.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFULLYCOMPATIBLE() {
        return fullycompatible;
    }

    /**
     * Définit la valeur de la propriété fullycompatible.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFULLYCOMPATIBLE(String value) {
        this.fullycompatible = value;
    }

    /**
     * Obtient la valeur de la propriété partconditiontemplateconditioncode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPARTCONDITIONTEMPLATECONDITIONCODE() {
        return partconditiontemplateconditioncode;
    }

    /**
     * Définit la valeur de la propriété partconditiontemplateconditioncode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPARTCONDITIONTEMPLATECONDITIONCODE(String value) {
        this.partconditiontemplateconditioncode = value;
    }

    /**
     * Obtient la valeur de la propriété recordid.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRecordid() {
        return recordid;
    }

    /**
     * Définit la valeur de la propriété recordid.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRecordid(Long value) {
        this.recordid = value;
    }

}

==> eam-wshub-proxyclient-12.0-sources.jar: net/datastream/schemas/mp_entities/substitutepart_001/SubstitutePart.java <==

package net.datastream.schemas.mp_entities.substitutepart_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.SUBSTITUTEPART_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SUBSTITUTEPARTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FULLYCOMPATIBLE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTCONDITIONTEMPLATECONDITIONCODE" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "substitutepartid",
    "fullycompatible",
    "partconditiontemplateconditioncode"
})
@XmlRootElement(name = "SubstitutePart")
public class SubstitutePart {

    @XmlElement(name = "SUBSTITUTEPARTID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected SUBSTITUTEPART_Type substitutepartid;
    @XmlElement(name = "FULLYCOMPATIBLE", namespace = "http://schemas.datastream.net/MP_fields", required = true, defaultValue = "false")
    protected String fullycompatible;
    @XmlElement(name = "PARTCONDITIONTEMPLATECONDITIONCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String partconditiontemplateconditioncode;
    @XmlAttribute(name = "recordid")
    protected Long recordid;

    /**
     * Gets the value of the substitutepartid property.
     * 
     * @return
     *     possible object is
     *     {@link SUBSTITUTEPART_Type }
     *     
     */
    public SUBSTITUTEPART_Type getSUBSTITUTEPARTID() {
        return substitutepartid;
    }

    /**
     * Sets the value of the substitutepartid property.
     * 
     * @param value
     *     allowed object is
     *     {@link SUBSTITUTEPART_Type }
     *     
     */
    public void setSUBSTITUTEPARTID(SUBSTITUTEPART_Type value) {
        this.substitutepartid = value;
    }

    /**
     * Gets the value of the fullycompatible property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFULLYCOMPATIBLE() {
        return fullycompatible;
    }

    /**
     * Sets the value of the fullycompatible property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFULLYCOMPATIBLE(String value) {
        this.fullycompatible = value;
    }

    /**
     * Gets the value of the partconditiontemplateconditioncode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPARTCONDITIONTEMPLATECONDITIONCODE() {
        return partconditiontemplateconditioncode;
    }

    /**
     * Sets the value of the partconditiontemplateconditioncode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPARTCONDITIONTEMPLATECONDITIONCODE(String value) {
        this.partconditiontemplateconditioncode = value;
    }

    /**
     * Gets the value of the recordid property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRecordid() {
        return recordid;
    }

    /**
     * Sets the value of the recordid property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRecordid(Long value) {
        this.recordid = value;
    }

}
